@@ -149,6 +149,7 @@ class Storage:
         if 'id' in data:
             self.id = data['id']
         if 'base64_bytes_array' in data:
+            # converts to image on load
             self.image = self._b64_to_image(data['base64_bytes_array'])
         if 'record_id' in data:
             self.record_id = data['record_id']
@@ -211,16 +212,16 @@ class FramesManager:
 
 
 if __name__ == "__main__":
-    f = FramesManager()
+    fm = FramesManager()
     jwt = input("Token: ")
-    f.set_jwt(jwt)
-    ids = f.search(lat=-33.918861, lon=18.423300, radius=1000)
+    fm.set_jwt(jwt)
+    ids = fm.search(lat=-33.918861, lon=18.423300, radius=1000)
 
     for id in ids:
-        record = f.get_record(id)
-        position = f.get_position(id)
-        weather = f.get_position(id)
-        storage = f.get_storage(id)
+        record = fm.get_record(id)
+        position = fm.get_position(id)
+        weather = fm.get_position(id)
+        storage = fm.get_storage(id)
 
         print(record.id)
 
